@@ -122,6 +122,7 @@ print_help (int argc, char *argv[])
   printf(_("  -i, --noini           Do not attempt to write dinksmallwood.ini\n"));
   printf(_("  -j, --nojoy           Do not attempt to use joystick\n"));
   printf(_("  -s, --nosound         Do not play sound\n"));
+  printf(_("  -t, --truecolor       Allow more colours (for recent D-Mod graphics)\n"));
   printf(_("  -w, --window          Use windowed mode instead of screen mode\n"));
   printf(_("  -7, --v1.07           Enable v1.07 compatibility mode\n"));
   printf("\n");
@@ -328,6 +329,11 @@ int init(int argc, char *argv[], char* splash_path)
      bring locale-specific behavior in the DinkC parsers. If that's a
      problem we may use some gnulib modules
      (cf. (gettext.info.gz)Triggering) */
+  /* Ex. with scanf("%f"...):
+     LANG=C            1.1 -> 1.100000
+     LANG=C            1,1 -> 1.000000
+     LANG=fr_FR.UTF-8  1.1 -> 1,000000
+     LANG=fr_FR.UTF-8  1,1 -> 1,100000 */
   /* setlocale (LC_ALL, ""); */
   setlocale(LC_MESSAGES, "");
   bindtextdomain(PACKAGE, LOCALEDIR);
@@ -402,7 +408,7 @@ int init(int argc, char *argv[], char* splash_path)
   /* The official v1.08 .exe runs 50-60 FPS in practice, despite the
      documented intent of running 83 FPS (or 12ms delay). */
   /* SDL_setFramerate(manager, 83); */
-  SDL_setFramerate(&framerate_manager, 60);
+  SDL_setFramerate(&framerate_manager, FPS);
 
   //dinks normal walk
   log_info("Loading batch...");
